@@ -61,9 +61,15 @@ class RAWImage(RAWPYobj):
 def RawImageBlock(**kwargs):
     "A `TransformBlock` for RAWImage"
     # print("RawImageBlock: ", kwargs.items())
-    parameters = rawpy.Params(**kwargs)
-    openFileMethod = partial(RAWImage.create, pr=parameters)
-    return TransformBlock(type_tfms=openFileMethod, batch_tfms=IntToFloatTensor)
+    parameters=rawpy.Params(**kwargs)
+    if kwargs['output_bps']==16:
+        output_bps=16
+        div=65535.
+    else:
+        output_bps=8
+        div=255.
+    openFileMethod=partial(RAWImage.create, pr=parameters,output_bps=output_bps)
+    return TransformBlock(type_tfms=openFileMethod, batch_tfms=IntToFloatTensor(div=div))
 
 # Cell
 # def ImageBlock(cls=RAWImage,**kwargs):
